#!/bin/sh
# Copyright IBM Corp. 2000-2001

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Configuration Based Update Installer
#----------------------------------------------------------------------------------
# Command Descriptions
# 
# The '-efix' option specifies an eFix update.
# The '-fixpack' option specifies a FixPack update.
# The '-install' option specifies an install action.
# The '-uninstall' option specifies an uninstall action.
# The '-installDir' option specifies the product install root location.
# The '-efixDir' option specifies the eFix directory.
# The '-fixpackDir' option specifies the FixPack directory.
# The '-efixes' specifies a list of eFixes to install or uninstall.
# The '-fixpackID' specifies a FixPack to install or uninstall.
# The '-efixDetails' option displays eFix detail information.
# The '-fixpackDetails' option displays FixPack detail information.
# The '-prereqOverride' option overrides any installation prerequisites.
# The '<propertyFile>.properties' option specifies an externally supplied parameters file.
#----------------------------------------------------------------------------------
# Launch Arguments:
#
# For EFix Processing:
#      updateSilent <propertiesFile>
#               ( -installDir <product install root>
#		  [ -efix ]
#                 [ -efixDir <efix repository root> ]
#                 [ -install | -uninstall | -uninstallAll ]
#                 [ -efixes <space delimited list of efixes> ]
#                 [ -efixJars <space delimited list of efix jars> ]
#                 [ -efixDetails ]
#                 [ -prereqOverride ] ) |
#               ( -help | -? | /help | /? | -usage )
#
# For FixPack Processing:
#  updateSilent <propertiesFile>
#	        ( -installDir <product install root>
#		  [ -fixpack ]
#                 [ ( -install | -uninstall
# 		      -fixpackDir <fixpack repository root> ]
# 	              -fixpackID <FixPack ID> ]
#		      [ ( -ihsInstallDir <IBM HTTP Server root> | -skipIHS ) ]
#		      [ ( -mqInstallDir <IBM Embedded Messaging> | -skipMQ ]
#		      [ -includeOptional <space delimited list of components> ]
#                  [ -fixpackDetails ] ) |
#            ( -help | -? | /help | /? | -usage )
#----------------------------------------------------------------------------------

# set DEBUG_UPDATE=yes to turn on debugging statements
DEBUG_UPDATE=

success_rc=0
fail_rc=$?

LaunchTitle=$0

launchInstaller=
useLocalJDK=
prepareJDK=
useJavaHome=
checkSetup=
callSetup=
checkClientSetup=
callClientSetup=
failSetup=
testJDK=
copyJDK=
failedCopyJDK=
okCopyJDK=

currentDir=`dirname $0`        
RUN_JAVA_HOME=
ARGS=

#----------------------------------------------------------------------------------
#  Initialization and setup
#----------------------------------------------------------------------------------
echo Start of [ "$LaunchTitle" ]
echo

echo Verifying installer jar:
echo   [ installer.jar ]
echo
if [ -f "$currentDir"/installer.jar ] 
   then
   ARGS=$@
   while [ $# -ne 0 ] # loop over arguments
do
    if [ $1 = "-skipJDKCopy" ]
        then
            echo No local copy of the JDK will be created.  
	    echo The installer will run directly from JAVA_HOME.
	    RUN_JAVA_HOME="yes"
            launchInstaller=1
    fi
    shift;
done

        JAVA_TMP="$currentDir"/java_tmp
        JAVA_EXE="$JAVA_TMP"/bin/java
        if [ -f "$JAVA_EXE" ]
           then 
               useLocalJDK=1
           else
               JRE_EXE="$currentDir"/java_tmp/jre/bin/java
               if [ -f "$JRE_EXE" ]
                 then
                    JAVA_TMP="$currentDir"/java_tmp/jre
                    useLocalJDK=1
                 else
                    if [ "$RUN_JAVA_HOME" = "yes" ]
                        then
                           launchInstaller=1  
                    else
                           prepareJDK=1
                    fi
               fi 
        fi
   else
        echo The installer jar file does not exist.  
        echo Exiting.
        echo
        exit $fail_rc
fi       


          
if [ "$useLocalJDK" ]
   then
        JAVA_HOME="$JAVA_TMP"
        if [ "$DEBUG_UPDATE" ] 
           then
        	echo Using the local copy of the JDK, made previously, for processing:
        	echo   JAVA_HOME: [ "$JAVA_HOME" ]
		echo 
	fi
        
        launchInstaller=1 	 
fi

if [ "$prepareJDK" ]
   then 
        if [ "$JAVA_HOME" ] 
           then 
                useJavaHome=1
           else
                checkClientSetup=1
        fi
fi


if [ "$checkClientSetup" ]
   then 
   	if [ "$DEBUG_UPDATE" ] 
           then
        	echo JAVA_HOME is not set.
        	echo Attempting to locate setupClient.sh
        	echo
        fi
        
        if [ -f "$currentDir"/../bin/setupClient.sh ]
           then
                callClientSetup=1
                JAVA_TMP="$currentDir"/java_tmp/jre
                JAVA_EXE="$JAVA_TMP"/bin/java
                checkSetup=
           else
                checkSetup=1
        fi
fi

if [ "$checkSetup" ]
   then 
   	if [ "$DEBUG_UPDATE" ] 
           then
        	echo JAVA_HOME is not set.
        	echo Attempting to locate setupCmdLine.sh
        	echo
        fi
        
        if [ -f "$currentDir"/../bin/setupCmdLine.sh ]
           then
                callSetup=1
           else
                failSetup=1
        fi
fi

if [ "$useJavaHome" ]
   then 
   	if [ "$DEBUG_UPDATE" ] 
           then
        	echo JAVA_HOME was set
        	echo     JAVA_HOME: [ "$JAVA_HOME" ]
        	echo
        fi
        
        testJDK=1
fi

if [ "$failSetup" ]
   then        
        echo JAVA_HOME and WAS_HOME must be set before launching the update wizard:
	echo     JAVA_HOME or WAS_HOME was not set
	echo     Set JAVA_HOME and WAS_HOME manually with the install_root/bin/setupCmdLine.sh or setupClient.sh script. 
        echo
	echo setupCmdLine.sh or setupClient.sh is usually located beneath your
	echo WebSphere installation, in the 'bin'
	echo directory. 
	echo
	echo Exiting.	
	echo
	exit $fail_rc 
fi

if [ "$callSetup" ]
   then                  
        . $currentDir/../bin/setupCmdLine.sh
        testJDK=1
fi

if [ "$callClientSetup" ]
   then
        . $currentDir/../bin/setupClient.sh
        testJDK=1
fi

if [ "$testJDK" ]; then
    if [ -f "$JAVA_HOME"/bin/java ]; then
        if [ "${WAS_HOME}" != "" ]; then 
            copyJDK=1
        else 
			echo     JAVA_HOME was not set to the WebSphere JDK
			echo     Set JAVA_HOME and WAS_HOME manually by sourcing the install_root/bin/setupCmdLine.sh or setupClient.sh script. 
        		echo
			echo setupCmdLine.sh or setupClient.sh is usually located beneath your
			echo WebSphere installation, in the 'bin'
			echo directory. 
			echo
			echo Exiting.	
			echo
			exit $fail_rc 
        fi           
    else
            echo The JDK was not found within the set JAVA_HOME
        	echo     JAVA_HOME: [ "$JAVA_HOME"/bin/java ]
        	echo
        	echo Exiting.
        	echo
        	exit $fail_rc
    fi           
fi        

PLATFORM=`uname`
export PLATFORM
                 
if [ "$copyJDK" ]
   then
        echo Making local copy of the JDK, which is required
	echo for PTF processing:
	echo   JAVA_HOME: [ "$JAVA_HOME" ]
	echo   JAVA_TMP:  [ "$JAVA_TMP" ]
	echo 
	
	if [ -d "$JAVA_TMP" ]
	   then 
                  if [ "$PLATFORM" = "AIX" ]; then
                     `slibclean`
                  fi;
	         `cp -r "$JAVA_HOME"/* "$JAVA_TMP"`
	         okCopyJDK=1
	   else
	         `mkdir -p "$JAVA_TMP"`
	         if [ -d "$JAVA_TMP" ]
	            then
	                 `cp -r "$JAVA_HOME"/* "$JAVA_TMP"`
	         
	                 if [ -f "$JAVA_TMP"/bin/java ] 
	                    then
	                          okCopyJDK=1	                 	  
	            	    else 
	                 	  failedCopyJDK=1
	                 fi
	           
	            else
	                  failedCopyJDK=1 
	         fi	         
	fi
fi	                
        
if [ "$failedCopyJDK" ]
   then
        echo The JDK could not be copied into the current directory.
	echo JAVA_HOME: [ "$JAVA_HOME" ]
	echo JAVA_TMP:  [ "$JAVA_TMP" ]
	echo
	echo Exiting.
	echo
	exit $fail_rc
fi

if [ "$okCopyJDK" ]
   then 
        echo The JDK was successfully copied
        echo 
        
        JAVA_HOME="$JAVA_TMP"
        launchInstaller=1
fi

	                   
#----------------------------------------------------------------------------------
# Set up library loading for native extfile libs
#----------------------------------------------------------------------------------

# Cases for platform specific goop.
case ${PLATFORM} in 
        Linux)
                # Need to do some minor analysis of threading mode.
                if [ ! "${LD_ASSUME_KERNEL}" = "" ] ; then
                    __OLD_LD_ASSUME_KERNEL=${LD_ASSUME_KERNEL}
                    unset LD_ASSUME_KERNEL
                    
                    # 0 == NPTL, 1 == LinuxThreads.
                    getconf GNU_LIBPTHREAD_VERSION 2>&1 | grep NPTL > /dev/null 2>&1
                    if [ $? -eq 0 ] ; then
                        # Set this parameter to insruct RPM v4 to force use of NPTL with RPM
                        # executions.
                        RPM_FORCE_NPTL=1
                        export RPM_FORCE_NPTL
                    fi
                    # Reset threading mode back what it was before
                    LD_ASSUME_KERNEL=${__OLD_LD_ASSUME_KERNEL}
                    export LD_ASSUME_KERNEL
                fi
        
                # Select the right arch library for the utils!
                OS_ARCH=`uname -m`
                case ${OS_ARCH} in
                    i386|i486|i586|i686|i786|i886|athlon)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/i386:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    ppc|ppc64)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/ppc32:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    s390)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/s390:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                esac
                ;;
        SunOS|Solaris)
                LD_LIBRARY_PATH=${currentDir}/lib/solaris:${LD_LIBRARY_PATH}
                export LD_LIBRARY_PATH
                ;;
        HP-UX)
                SHLIB_PATH=${currentDir}/lib/hpux:${SHLIB_PATH}
                export SHLIB_PATH
                
                # Make sure this is executable or it won't load!
                if [ ! -x ${currentDir}/lib/hpux/libUnixFileUtils.sl ] ; then
                    chmod 755 ${currentDir}/lib/hpux/libUnixFileUtils.sl
                fi                 
                ;;
        AIX)    
                LIBPATH=${currentDir}/lib/aix:${LIBPATH}
                export LIBPATH
                ;;
        *)
                echo "Unknown platform: ${PLATFORM}.  Native file libraries will not be loaded."
                ;;
esac


#----------------------------------------------------------------------------------
# Installer application execution
#----------------------------------------------------------------------------------

if [ "$launchInstaller" ] 
  then          
       if [ -f /etc/mvl-release ]
           then
              "$JAVA_HOME"/bin/java \
	      -Xmx256m \
 	      -cp "$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar \
 	      -DCURRENT_UPDATE_DIR="${currentDir}" \
              com.ibm.websphere.update.launch.Launcher \
              com.ibm.websphere.update.silent.UpdateInstaller $ARGS
           else
              "$JAVA_HOME"/bin/java \
	      -Xmx256m \
 	      -cp "$currentDir"/installer.jar:"$currentDir"/lib/extfile.jar \
 	      -DCURRENT_UPDATE_DIR="${currentDir}" \
  	      com.ibm.websphere.update.silent.SilentArgsCollector $ARGS
       fi              
fi

echo End of [ "$LaunchTitle" ]
echo 
exit $success_rc
